import { Injectable } from '@angular/core';
import { DropdownField } from '../../app/form/fields/dropdown/field-dropdown';
import { FieldBase } from '../../app/form/fields/field-base';
import { TextboxField } from '../../app/form/fields/textbox/field-textbox';
import { CheckBoxField } from '../../app/form/fields/checkbox/field-checkbox';
import { DataModel } from '../entities/DataModel';
import {Rule} from '../entities/common/rule';
import { GroupBase } from '../form/dynamic-form-group/group-base';

@Injectable()
export class dataModelBuilder {

   private dataModel : DataModel;
  
   public getDataModel(data){ 
      
      if(this.dataModel != null)
        return this.dataModel;
      
      this.dataModel = new DataModel();
      this.dataModel.fields = this.getFieldVisibility(data.dataset.profile.viewstyle.definition.root.fields.field);
      this.dataModel.groups = 
                            //this.getGroups(data.dataset.profile.viewstyle.definition.root.fieldGroups.fieldGroup, this.dataModel.fields);
                            this.getDummyGroups();
                                
      return this.dataModel;
    }
  
  
    private getFieldVisibility(fields:any[]) {
        console.log(fields);
        let fieldsVisible :FieldBase<any>[] =[];
            fields.forEach(element => {                    
                if (element.viewStyle._renderstyle == "freetext"){
                    let newfield:FieldBase <any>;
                    let rule = new Rule();
                    //rule.target = element.visible.rule._target;
                    //rule.ruleType = element.visible.rule._type;
                     newfield = new TextboxField({
                            label: element._attribute,
                            key:element.title._id,
                            value: 'DMP1',
                            required: true,
                            ordinal:element._ordinal,
                            rules: new Array(),
                            visible: true,
                            group : element._group
                        });
                        if (element.visible.rule)
                            if(element.visible.rule.length){
                                element.visible.rule.forEach(rule => {
                                    newfield.rules.push(rule)
                                });
                            }
                            else {
                                newfield.rules.push(element.visible.rule)
                            }
                            
                        fieldsVisible.push(newfield);
                }  
                else if (element.viewStyle._renderstyle == "combobox"){
                    let newfield:DropdownField;
                    let rule = new Rule();
                    //rule.target = element.visible.rule._target;
                    //rule.ruleType = element.visible.rule._type;
                     newfield = new DropdownField({
                            label: element._attribute,
                            key:element.title._id,
                            value: 'DMP1',
                            required: true,
                            ordinal:element._ordinal,
                            rule: element.visible.rule,
                            visible: true                         
                        });
                        fieldsVisible.push(newfield);
                }
                else if (element.viewStyle._renderstyle == "checkbox"){
                    let newfield:CheckBoxField;
                    //rule.target = element.visible.rule._target;
                    //rule.ruleType = element.visible.rule._type;
                     newfield = new CheckBoxField({
                            label: element._attribute,
                            key:element._id,
                            value: true,
                            required: true,
                            ordinal:element._ordinal,
                            rule: element.visible.rule,
                            visible: true                         
                        });
                        fieldsVisible.push(newfield);
                }                 
            });
            fieldsVisible.sort((a, b) => a.order - b.order);
            return  fieldsVisible;
    }

    private getGroups(fieldGroups:any[], fields:any[]){
        let groups :GroupBase<any>[] =[];

        fieldGroups.forEach(fieldGroup =>{
          let  newfldGroup = new GroupBase();
          newfldGroup.groupFields = new Array();
          fields.forEach(field => {
              if(fieldGroup._id == field.group){
                newfldGroup.groupFields.push(field);
              }
          });
          newfldGroup.title = fieldGroup.title.__cdata;
          groups.push(newfldGroup)
        });
        return groups;
    }
  

     private getDummyGroups(){
      
       let groups :GroupBase<any>[] =[];
      
      
       let group: GroupBase<any>;
       group = new GroupBase<any>({
         key: "adfgadfsg",
         title: "GroupA",
         rules: new Array(),
         groupFields: new Array(),
         value: "value",
         visible: true,
         order: 1
         //,
         //controlType: "none"
       });
      
      
       let newfield1:FieldBase <any>;
       newfield1 = new TextboxField({
               key:"tf1-455",
               label: "Field from group1",
               value: 'this is a groupfield',
               required: true,
               ordinal:1
           });
       group.groupFields.push(newfield1);
      
       let newfield2:FieldBase <any>;
       newfield2 = new TextboxField({
               key:"tf1-443",
               label: "Another field from group1",
               value: 'this is a groupfield',
               required: true,
               ordinal:2
           });
       group.groupFields.push(newfield2);
      
       groups.push(group);
      

       return groups;
      
     }
 
  
}